# Table of Contents

* Python version and dependencies
* Code formatting
* PEP8

## Python version and dependencies

Current development is done with Python 3.7+

Dependencies can be managed with [pip-tools](https://github.com/jazzband/pip-tools).

## Code formatting

We encourage the use of the [Black](https://black.readthedocs.io/en/stable/) code formatter.

## PEP8

Please follow all PEP8 standards except for the antiquated 80 column rule.
